@@ -10,13 +10,13 @@ Created on Tue Sep 15 11:28:02 2020
 import xarray as xr
 import numpy as np
 import pandas as pd
+
 #%%
 
-def compute_percentile(data, 
-                        perc, 
-                        weights=None):
+
+def compute_percentile(data, perc, weights=None):
     """
-    Fnction to compute the unweighted and weighted percentile for 
+    Fnction to compute the unweighted and weighted percentile for
     clustered country-level data
 
     Parameters
@@ -33,28 +33,26 @@ def compute_percentile(data,
     None.
 
     """
-    
+
     # un-weighted
     if weights is None:
         mask = ~np.isnan(data)
         data = data[mask]
-        result  = np.percentile(data, perc*100)
+        result = np.percentile(data, perc * 100)
         return result
-    
-    
+
     # weighted
     mask = ~np.isnan(data)
     data = data[mask]
     weights = weights[mask]
-    
-    
+
     ix = np.argsort(data)
-    
+
     # Sort data and weights
     sort_data = data[ix]
     sort_weights = weights[ix]
-    
+
     cdf = (np.cumsum(sort_weights) - 0.5 * sort_weights) / np.sum(sort_weights)
     result = np.interp(perc, cdf, sort_data)
-    
-    return result
\ No newline at end of file
+
+    return result
